boolean_cayley_graphs: Investigations of Boolean functions, their Cayley graphs, and associated structures
==========================================================================================================

Description
-----------

Investigations of Boolean functions, their Cayley graphs, and associated structures

License
-------

GPLv3

Upstream Contact
----------------

- https://pypi.org/project/boolean-cayley-graphs/
- https://github.com/passagemath/passagemath-pkg-Boolean-Cayley-graphs
